@@ -2,10 +2,10 @@ sub Mojo::Webqq::Client::change_state{
     my $self = shift;
     my $state = shift;
     my $api_url = 'http://d.web2.qq.com/channel/change_status2';
-    my $headers  = (
+    my $headers  = {
         Referer => 'http://d.web2.qq.com/proxy.html?v=20130916001&callback=1&id=2',
         json    => 1,
-    );
+    };
     my @query_string = (
         newstatus       =>  $state,
         clientid        =>  $self->clientid,
