@@ -97,7 +97,7 @@ sub is_empty{
 sub update{
     my $self = shift;
     my $hash = shift;
-    for(keys %$self){
+    for(grep {substr($_,0,1) ne "_"} keys %$self){
         if($_ eq "member" and ref $hash->{member} eq "ARRAY"){
             next if not @{$hash->{member}};
             my @member = map {ref($_ eq "Mojo::Webqq::Group::Member")?$_:$self->{_client}->new_group_member->new($_)} @{$hash->{member}};
@@ -108,11 +108,11 @@ sub update{
                 my($new_members,$lost_members,$sames)=$self->{_client}->array_diff($self->member, \@member,sub{$_[0]->id});
                 for(@{$new_members}){
                     $self->add_group_member($_);
-                    $self->{_client}->emit(new_group_member=>$_);
+                    $self->{_client}->emit(new_group_member=>$_) if defined $self->{_client};
                 }
                 for(@{$lost_members}){
                     $self->remove_group_member($_);
-                    $self->{_client}->emit(lose_group_member=>$_);
+                    $self->{_client}->emit(lose_group_member=>$_) if defined $self->{_client};
                 }
                 for(@{$sames}){
                     my($old_member,$new_member) = ($_->[0],$_->[1]);
@@ -128,14 +128,14 @@ sub update{
                         my $old_property = $self->{$_};
                         my $new_property = $hash->{$_};
                         $self->{$_} = $hash->{$_};
-                        $self->{_client}->emit("group_property_change"=>$self,$_,$old_property,$new_property);
+                        $self->{_client}->emit("group_property_change"=>$self,$_,$old_property,$new_property) if defined $self->{_client};
                     }
                 }
                 elsif( ! (!defined $hash->{$_} and !defined $self->{$_}) ){
                     my $old_property = $self->{$_};
                     my $new_property = $hash->{$_};
                     $self->{$_} = $hash->{$_};
-                    $self->{_client}->emit("group_property_change"=>$self,$_,$old_property,$new_property);
+                    $self->{_client}->emit("group_property_change"=>$self,$_,$old_property,$new_property) if defined $self->{_client};
                 }
             }
         }
